# PyNetBox Documentation

## TL;DR
Instantiate the `Api` class. Use the methods available on `Endpoint` to return `Record` objects.

## API Reference

::: pynetbox.core.api.Api
    handler: python
    options:
        members:
            - __init__
            - create_token
            - openapi
            - status
            - version
            - activate_branch
        show_source: true
        show_root_heading: true

## App Reference

::: pynetbox.core.app.App
    handler: python
    options:
        members:
            - config
        show_source: true
        show_root_heading: true 